Enum TypeError
#[non_exhaustive]pub enum TypeError {
InvalidModule {
got: char,
},
InvalidCallsign {
reason: &'static str,
},
InvalidSuffix {
reason: &'static str,
},
InvalidReflectorCallsign {
reason: &'static str,
},
InvalidBandLetter {
got: char,
},
}Expand description
Validation errors for dstar-gateway-core strong types.
All try_from_* constructors on the typed primitives in
[crate::types] return this error on rejection.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidModule
Supplied module character is not ASCII A-Z.
InvalidCallsign
Supplied callsign is empty, too long, or contains non-ASCII.
InvalidSuffix
Supplied suffix is too long, or contains non-ASCII.
InvalidReflectorCallsign
Supplied reflector callsign does not match a known protocol prefix.
InvalidBandLetter
Supplied band letter is not A, B, C, or D.